@@ -88,28 +88,62 @@ class RunXGBoostClassifierAPI(BaseEstimatorAPI):
         super().__init__(import_name)
         self.clf_name = None
         self.result_metric = None  # Store the computed metric result
+        self.param_space = hyperparameter_search_space
 
     def get_hyperparameter_search_space(self):
         clf = self.params.model
-        return hyperparameter_search_space[clf]
+        return self.param_space.get(clf, {})
+
+    def _validate_kwargs(self, clf_name: str, kwargs: dict):
+        """Validate that provided hyperparameters are allowed for this classifier."""
+        if clf_name not in self.param_space:
+            return
+        allowed = set(self.param_space[clf_name].keys())
+        unknown = set(kwargs) - allowed
+        if unknown:
+            raise ValueError(
+                f"Unsupported parameters for '{clf_name}': {sorted(unknown)}. "
+                f"Allowed: {sorted(allowed)}"
+            )
+
+    def _get_default_params(self, clf_name: str) -> dict:
+        """Get default hyperparameters for a classifier."""
+        if clf_name not in self.param_space:
+            return {}
+
+        defaults = {}
+        for param_name, param_config in self.param_space[clf_name].items():
+            if 'default' in param_config:
+                defaults[param_name] = param_config['default']
+        return defaults
 
     def fit(self, args, X_train, y_train, X_test, y_test):
-        clf = self.params.model
-        params = self.dict_to_namespace()
+        clf_name = self.params.model
+        self.clf_name = clf_name
 
+        # Get hyperparameters from params (if provided)
         try:
-            clf_params = self.params.params
+            clf_kwargs = self.params.params if hasattr(self.params, 'params') and self.params.params else {}
         except AttributeError:
-            pass
+            clf_kwargs = {}
 
-        if clf in clfs.keys():
-            classifier = clfs[clf]
-            self.clf_name = clf
+        # Validate hyperparameters
+        self._validate_kwargs(clf_name, clf_kwargs)
+
+        # Merge with defaults
+        final_params = {**self._get_default_params(clf_name), **clf_kwargs}
+
+        # Instantiate classifier with hyperparameters
+        if clf_name == "ensemble":
+            classifier = XGBClassifier(random_state=42, **final_params)
         else:
-            raise Exception("Model {} not defined in model.py".format(clf))
-
-        # TODO add setting params for clf
+            # Fallback to old hardcoded dict
+            if clf_name in clfs.keys():
+                classifier = clfs[clf_name]
+            else:
+                raise Exception(f"Classifier '{clf_name}' not defined")
 
+        logging.info(f"Training {clf_name} with params: {final_params}")
         classifier.fit(X_train, y_train)
         logging.info("finished classifier training")
 
