@@ -27,26 +27,60 @@ class RunSklearnImputerAPI(BaseTransformerAPI):
         super().__init__(__name__)
         self.result = None
 
-    def get_hyperparameter_search_space(self):
-        param_spaces = {
-            # "miwae": {
-            #     "batch_size": [64, 128, 256],
-            #     "epochs": [50, 100, 150],
-            #     "latent_dim": [8, 16, 32],
-            #     "lr": [1e-4, 5e-4, 1e-3],
-            # },
-            # "miracle": {
-            #     "n_components": [5, 10, 20, 40],
-            #     "tol": [1e-4, 1e-3],
-            #     "max_iter": [100, 200, 400],
-            # },
+        # Define hyperparameter search space
+        self.param_space = {
+            "knn": {
+                "n_neighbors": {
+                    "type": "int",
+                    "min": 1,
+                    "max": 15,
+                    "default": 5
+                },
+                "weights": {
+                    "type": "categorical",
+                    "choices": ["uniform", "distance"],
+                    "default": "uniform"
+                }
+            },
+            "ii": {
+                "max_iter": {
+                    "type": "int",
+                    "min": 5,
+                    "max": 50,
+                    "default": 10
+                },
+                "tol": {
+                    "type": "float",
+                    "min": 1e-5,
+                    "max": 1e-2,
+                    "default": 1e-3,
+                    "log_scale": True
+                }
+            }
         }
-        return param_spaces
+
+    def get_hyperparameter_search_space(self):
+        return self.param_space
+
+    def _validate_kwargs(self, model_name: str, kwargs: dict):
+        """Validate that provided hyperparameters are allowed for this imputer."""
+        if model_name not in self.param_space:
+            return
+        allowed = set(self.param_space[model_name].keys())
+        unknown = set(kwargs) - allowed
+        if unknown:
+            raise ValueError(
+                f"Unsupported parameters for '{model_name}': {sorted(unknown)}. "
+                f"Allowed: {sorted(allowed)}"
+            )
 
     def fit(self, params, *args, **kwargs):
         model = params.model
-        imputer_kwargs = params.imputer_kwargs
-        categorical_columns = params.categorical_columns
+        imputer_kwargs = params.imputer_kwargs if hasattr(params, 'imputer_kwargs') and params.imputer_kwargs else {}
+        categorical_columns = params.categorical_columns if hasattr(params, 'categorical_columns') else None
+
+        # Validate hyperparameters
+        self._validate_kwargs(model, imputer_kwargs)
 
         # Handle both data formats: full dataset (string) or just X_train
         if 'data' in kwargs:
@@ -62,6 +96,7 @@ class RunSklearnImputerAPI(BaseTransformerAPI):
         # Fit the imputer on training data and transform it
         factory = imps[model]
         imputer = factory(**imputer_kwargs)
+        logging.info(f"Imputing with {model} using params: {imputer_kwargs}")
         X_train_imputed = imputer.fit_transform(X_train)
 
         # Store column info
