@@ -36,6 +36,12 @@ class RunSklearnImpute(BaseTransformer):
 
     @cached_property
     def payload(self):
+        # Get hyperparameters: first check args.hyperparams, then fall back to self.imputer_kwargs
+        imputer_params = self.imputer_kwargs  # From constructor
+        if hasattr(self.args, 'hyperparams') and self.args.hyperparams:
+            # Override with hyperparams from args if provided
+            imputer_params = self.args.hyperparams.get(self.model, imputer_params)
+
         # Imputers only need X (features), not y (target)
         # Imputation is unsupervised - it fills missing values based on feature patterns
         # Files are saved to /data/interim/{dataset_name}/
@@ -48,7 +54,7 @@ class RunSklearnImpute(BaseTransformer):
                 # f"{self.args.dataset}/X_test_{self.container_name}.csv"
             ],
             "categorical_columns": self.categorical_columns,
-            "imputer_kwargs": self.imputer_kwargs,
+            "imputer_kwargs": imputer_params,  # Pass hyperparameters
             "impute_file_name": self.impute_file_name
         }
 
