@@ -11,8 +11,13 @@ from ..processing.preprocessing import DataPreprocess
 from .pipeline_strategies import (
     ThreeElementPipelineStrategy,
     HybridPipelineStrategy,
-    AutoMLPipelineStrategy
+    AutoMLPipelineStrategy,
+    SurvivalPipelineStrategy,
+    UnsupervisedPipelineStrategy,
+    SurvivalUnsupervisedPipelineStrategy
 )
+from ..pipelines.customsurvival import survival_models
+from ..pipelines.customunsupervised import unsupervised_models, survival_unsupervised_models
 
 class RunPipe:
     """ Run different pipelines and save the trained results
@@ -56,7 +61,7 @@ class RunPipe:
 
     def _get_strategy(self, pipe):
         """
-        Select the appropriate pipeline strategy based on pipeline length.
+        Select the appropriate pipeline strategy based on pipeline length and components.
 
         Args:
             pipe: Pipeline specification (list of component names)
@@ -67,15 +72,37 @@ class RunPipe:
         pipe_length = len(pipe)
 
         if pipe_length == 3:
-            # Imputer -> Resampler -> Classifier
-            return ThreeElementPipelineStrategy(
-                self.args, self.dataloader, self.preprocessor, self.saver
-            )
+            # Check if this is a survival pipeline by examining the model (third element)
+            model = pipe[2]
+            if model in survival_models:
+                # Imputer -> Survival Resampler -> Survival Model
+                return SurvivalPipelineStrategy(
+                    self.args, self.dataloader, self.preprocessor, self.saver
+                )
+            else:
+                # Imputer -> Resampler -> Classifier
+                return ThreeElementPipelineStrategy(
+                    self.args, self.dataloader, self.preprocessor, self.saver
+                )
         elif pipe_length == 2:
-            # Imputer -> Hybrid Method
-            return HybridPipelineStrategy(
-                self.args, self.dataloader, self.preprocessor, self.saver
-            )
+            # Check if this is an unsupervised pipeline by examining the second element
+            model = pipe[1]
+
+            if model in survival_unsupervised_models:
+                # Imputer -> Survival Unsupervised Model
+                return SurvivalUnsupervisedPipelineStrategy(
+                    self.args, self.dataloader, self.preprocessor, self.saver
+                )
+            elif model in unsupervised_models:
+                # Imputer -> Unsupervised Model (clustering, reduction, anomaly)
+                return UnsupervisedPipelineStrategy(
+                    self.args, self.dataloader, self.preprocessor, self.saver
+                )
+            else:
+                # Imputer -> Hybrid Method
+                return HybridPipelineStrategy(
+                    self.args, self.dataloader, self.preprocessor, self.saver
+                )
         elif pipe_length == 1:
             # AutoML only
             return AutoMLPipelineStrategy(
@@ -84,7 +111,7 @@ class RunPipe:
         else:
             raise ValueError(
                 f"Invalid pipeline length {pipe_length}. "
-                f"Expected 1 (AutoML), 2 (Hybrid), or 3 (Regular) elements."
+                f"Expected 1 (AutoML), 2 (Hybrid/Unsupervised), 3 (Regular/Survival) elements."
             )
 
     def impute_data(self, imp, train_ratio=1.0):
@@ -128,45 +155,63 @@ class RunPipe:
             X, y = self.stratifiedSample(X, y, train_ratio)
         return X, y
 
-    def fit_automl(self, pipe, train_ratio=1.0):
+    def fit_automl(self, pipe, train_ratio=1.0, hyperparams=None):
         """
         Execute a 1-element AutoML pipeline.
 
         Args:
             pipe: Pipeline with 1 element (AutoML method name)
             train_ratio: Fraction of data to use (default 1.0)
+            hyperparams: Dict mapping component names to hyperparameters (optional)
+                         e.g., {'autosklearn': {...}}
 
         Returns:
             Result from AutoML execution
         """
+        # Store hyperparams in args for components to access
+        if hyperparams:
+            self.args.hyperparams = hyperparams
+
         strategy = self._get_strategy(pipe)
         return strategy.execute(pipe, train_ratio)
 
-    def fit_hybrid(self, pipe, train_ratio=1.0):
+    def fit_hybrid(self, pipe, train_ratio=1.0, hyperparams=None):
         """
         Execute a 2-element hybrid pipeline (Imputer -> Hybrid Method).
 
         Args:
             pipe: Pipeline with 2 elements [imputer, hybrid_method]
             train_ratio: Fraction of data to use (default 1.0)
+            hyperparams: Dict mapping component names to hyperparameters (optional)
+                         e.g., {'median': {}, 'autosmote': {...}}
 
         Returns:
             Average result across all K-folds
         """
+        # Store hyperparams in args for components to access
+        if hyperparams:
+            self.args.hyperparams = hyperparams
+
         strategy = self._get_strategy(pipe)
         return strategy.execute(pipe, train_ratio)
 
-    def fit(self, pipe, train_ratio=1.0):
+    def fit(self, pipe, train_ratio=1.0, hyperparams=None):
         """
         Execute a 3-element pipeline (Imputer -> Resampler -> Classifier).
 
         Args:
             pipe: Pipeline with 3 elements [imputer, resampler, classifier]
             train_ratio: Fraction of data to use (default 1.0)
+            hyperparams: Dict mapping component names to hyperparameters (optional)
+                         e.g., {'smote': {'k_neighbors': 7}, 'lr': {'C': 0.1, 'penalty': 'l1'}}
 
         Returns:
             Average result across all K-folds
         """
+        # Store hyperparams in args for components to access
+        if hyperparams:
+            self.args.hyperparams = hyperparams
+
         strategy = self._get_strategy(pipe)
         return strategy.execute(pipe, train_ratio)
 
