@@ -1,9 +1,13 @@
 import numpy as np
-from ..components.automls import RunAutoSklearn
+from ..components.automls import RunH2O, RunTPOT, RunAutoSklearn
 
 
+# AutoML systems - using lazy initialization pattern (lambdas)
+# to avoid instantiation errors before data_folder is set
 automls = {
-    "autosklearn": RunAutoSklearn()
+    "h2o": lambda data_folder: RunH2O(data_folder=data_folder),
+    "tpot": lambda data_folder: RunTPOT(data_folder=data_folder),
+    "autosklearn": lambda data_folder: RunAutoSklearn(data_folder=data_folder),
 }
 
 class CustomAutoML:
